@@ -11,9 +11,11 @@ import { Command } from '@oclif/command'
 import * as Listr from 'listr'
 
 import { CheHelper } from '../api/che'
+import { CheApiClient } from '../api/che-api-client'
 import { KubeHelper } from '../api/kube'
 import { OpenShiftHelper } from '../api/openshift'
-import { DOCS_LINK_AUTH_TO_CHE_SERVER_VIA_OPENID } from '../constants'
+import { VersionHelper } from '../api/version'
+import { DOC_LINK, DOC_LINK_OBTAIN_ACCESS_TOKEN, DOC_LINK_OBTAIN_ACCESS_TOKEN_OAUTH, DOC_LINK_RELEASE_NOTES } from '../constants'
 
 import { KubeTasks } from './kube'
 
@@ -46,6 +48,8 @@ export class CheTasks {
 
   cheOperatorSelector = 'app=codeready-operator'
 
+  cheConsoleLinkName = 'che'
+
   constructor(flags: any) {
     this.kube = new KubeHelper(flags)
     this.kubeTasks = new KubeTasks(flags)
@@ -93,7 +97,6 @@ export class CheTasks {
         enabled: ctx => !ctx.isCheReady,
         task: () => this.kubeTasks.podStartTasks(command, this.cheSelector, this.cheNamespace)
       },
-      ...this.retrieveEclipseCheUrl(flags),
       ...this.checkEclipseCheStatus()
     ]
   }
@@ -191,8 +194,9 @@ export class CheTasks {
           let cheURL = ''
           try {
             cheURL = await this.che.cheURL(this.cheNamespace)
-            const status = await this.che.getCheServerStatus(cheURL)
-            ctx.isAuthEnabled = await this.che.isAuthenticationEnabled(cheURL)
+            const cheApi = CheApiClient.getInstance(cheURL + '/api')
+            const status = await cheApi.getCheServerStatus()
+            ctx.isAuthEnabled = await cheApi.isAuthenticationEnabled()
             const auth = ctx.isAuthEnabled ? '(auth enabled)' : '(auth disabled)'
             task.title = `${task.title}...${status} ${auth}`
           } catch (error) {
@@ -254,16 +258,13 @@ export class CheTasks {
     return [{
       title: 'Stop CodeReady Workspaces server and wait until it\'s ready to shutdown',
       enabled: (ctx: any) => !ctx.isCheStopped,
-      task: async (ctx: any, task: any) => {
-        if (ctx.isAuthEnabled && !this.cheAccessToken) {
-          command.error('E_AUTH_REQUIRED - CodeReady Workspaces authentication is enabled and an access token need to be provided (flag --access-token). ' +
-            `For instructions to retrieve a valid access token refer to ${DOCS_LINK_AUTH_TO_CHE_SERVER_VIA_OPENID}`)
-        }
+      task: async (task: any) => {
         try {
           const cheURL = await this.che.cheURL(this.cheNamespace)
-          await this.che.startShutdown(cheURL, this.cheAccessToken)
-          await this.che.waitUntilReadyToShutdown(cheURL)
-          task.title = await `${task.title}...done`
+          const cheApi = CheApiClient.getInstance(cheURL + '/api')
+          await cheApi.startCheServerShutdown(this.cheAccessToken)
+          await cheApi.waitUntilCheServerReadyToShutdown()
+          task.title = `${task.title}...done`
         } catch (error) {
           command.error(`E_SHUTDOWN_CHE_SERVER_FAIL - Failed to shutdown CodeReady Workspaces server. ${error.message}`)
         }
@@ -419,6 +420,18 @@ export class CheTasks {
           }
           task.title = await `${task.title}...OK`
         }
+      },
+      {
+        title: `Delete consoleLink ${this.cheConsoleLinkName}`,
+        task: async (_ctx: any, task: any) => {
+          const consoleLinkExists = await this.kube.consoleLinkExists(this.cheConsoleLinkName)
+          const checlusters = await this.kube.getAllCheCluster()
+          // Delete the consoleLink only in case if there no more checluster installed
+          if (checlusters.length === 0 && consoleLinkExists) {
+            await this.kube.deleteConsoleLink(this.cheConsoleLinkName)
+          }
+          task.title = `${task.title}...OK`
+        }
       }]
   }
 
@@ -465,12 +478,25 @@ export class CheTasks {
     ]
   }
 
+  deleteNamespace(flags: any): ReadonlyArray<Listr.ListrTask> {
+    return [{
+      title: `Delete namespace ${flags.chenamespace}`,
+      task: async (task: any) => {
+        const namespaceExist = await this.kube.namespaceExist(flags.chenamespace)
+        if (namespaceExist) {
+          await this.kube.deleteNamespace(flags.chenamespace)
+        }
+        task.title = `${task.title}...OK`
+      }
+    }]
+  }
+
   verifyCheNamespaceExistsTask(flags: any, command: Command): ReadonlyArray<Listr.ListrTask> {
     return [{
       title: `Verify if namespace '${flags.chenamespace}' exists`,
       task: async () => {
         if (!await this.che.cheNamespaceExist(flags.chenamespace)) {
-          command.error(`E_BAD_NS - Namespace does not exist.\nThe Kubernetes Namespace "${flags.chenamespace}" doesn't exist. The configuration cannot be injected.\nFix with: verify the namespace where workspace is running (kubectl get --all-namespaces deployment | grep workspace)`, { code: 'EBADNS' })
+          command.error(`E_BAD_NS - Namespace does not exist.\nThe Kubernetes Namespace "${flags.chenamespace}" doesn't exist.`, { code: 'EBADNS' })
         }
       }
     }]
@@ -539,18 +565,6 @@ export class CheTasks {
     ]
   }
 
-  workspaceLogsTasks(namespace: string, workspaceId: string): ReadonlyArray<Listr.ListrTask> {
-    return [
-      {
-        title: 'Read workspace logs',
-        task: async (ctx: any, task: any) => {
-          ctx['workspace-run'] = await this.che.readWorkspacePodLog(namespace, workspaceId, ctx.directory)
-          task.title = `${task.title}...done`
-        }
-      }
-    ]
-  }
-
   namespaceEventsTask(namespace: string, command: Command, follow: boolean): ReadonlyArray<Listr.ListrTask> {
     return [
       {
@@ -597,13 +611,43 @@ export class CheTasks {
     ]
   }
 
-  retrieveEclipseCheUrl(flags: any): ReadonlyArray<Listr.ListrTask> {
+  preparePostInstallationOutput(flags: any): ReadonlyArray<Listr.ListrTask> {
     return [
       {
-        title: 'Retrieving CodeReady Workspaces server URL',
+        title: 'Prepare post installation output',
         task: async (ctx: any, task: any) => {
-          ctx.cheURL = await this.che.cheURL(flags.chenamespace)
-          task.title = `${task.title}... ${ctx.cheURL}`
+          const version = await VersionHelper.getCheVersion(flags)
+          ctx.highlightedMessages.push(`CodeReady Workspaces ${version.trim()} has successfully installed.`)
+
+          const cheUrl = await this.che.cheURL(flags.chenamespace)
+          ctx.highlightedMessages.push(`Users can access the Dashboard at   : ${cheUrl}`)
+
+          const cheConfigMap = await this.kube.getConfigMap('che', flags.chenamespace)
+          if (cheConfigMap && cheConfigMap.data) {
+            if (cheConfigMap.data.CHE_WORKSPACE_PLUGIN__REGISTRY__URL) {
+              ctx.highlightedMessages.push(`Plugins can be viewed at            : ${cheConfigMap.data.CHE_WORKSPACE_PLUGIN__REGISTRY__URL}`)
+            }
+            if (cheConfigMap.data.CHE_WORKSPACE_DEVFILE__REGISTRY__URL) {
+              ctx.highlightedMessages.push(`Devfiles can be viewed at           : ${cheConfigMap.data.CHE_WORKSPACE_DEVFILE__REGISTRY__URL}`)
+            }
+            if (cheConfigMap.data.CHE_KEYCLOAK_AUTH__SERVER__URL) {
+              ctx.highlightedMessages.push(`Identity provider can be accessed at: ${cheConfigMap.data.CHE_KEYCLOAK_AUTH__SERVER__URL}`)
+            }
+            ctx.highlightedMessages.push(`Product documentation is at         : ${DOC_LINK}`)
+            if (DOC_LINK_RELEASE_NOTES) {
+              ctx.highlightedMessages.push(`Release Notes are at                : ${DOC_LINK_RELEASE_NOTES}`)
+            }
+          }
+
+          const cheCluster = await this.kube.getCheCluster(flags.chenamespace)
+          if (cheCluster && cheCluster.spec.auth && cheCluster.spec.auth.updateAdminPassword) {
+            ctx.highlightedMessages.push('CodeReady Workspaces admin credentials       : "admin:admin". You will be asked to change default Che admin password on the first login.')
+          }
+          if (ctx.identityProviderUsername && ctx.identityProviderPassword) {
+            ctx.highlightedMessages.push(`Identity Provider credentials       : "${ctx.identityProviderUsername}:${ctx.identityProviderPassword}".`)
+          }
+
+          task.title = `${task.title}...done`
         }
       }
     ]
@@ -613,7 +657,10 @@ export class CheTasks {
     return [
       {
         title: 'CodeReady Workspaces status check',
-        task: async ctx => this.che.isCheServerReady(ctx.cheURL)
+        task: async ctx => {
+          const cheApi = CheApiClient.getInstance(ctx.cheURL + '/api')
+          return cheApi.isCheServerReady()
+        }
       }
     ]
   }
@@ -623,9 +670,11 @@ export class CheTasks {
       {
         title: 'Checking authentication',
         task: async (ctx: any, task: any) => {
-          ctx.isAuthEnabled = await this.che.isAuthenticationEnabled(ctx.cheURL)
+          const cheApi = CheApiClient.getInstance(ctx.cheURL + '/api')
+          ctx.isAuthEnabled = await cheApi.isAuthenticationEnabled()
           if (ctx.isAuthEnabled && !this.cheAccessToken) {
-            throw new Error('E_AUTH_REQUIRED - CodeReady Workspaces authentication is enabled but access token is missed. Use --access-token to provide access token.')
+            throw new Error('E_AUTH_REQUIRED - CodeReady Workspaces authentication is enabled and an access token is needed to be provided (flag --access-token). ' +
+              `See the documentation how to obtain token: ${DOC_LINK_OBTAIN_ACCESS_TOKEN} and ${DOC_LINK_OBTAIN_ACCESS_TOKEN_OAUTH}.`)
           }
           task.title = `${task.title}... ${ctx.isAuthEnabled ? '(auth enabled)' : '(auth disabled)'}`
         }
